# github-content [![NPM version](https://img.shields.io/npm/v/github-content.svg?style=flat)](https://www.npmjs.com/package/github-content) [![NPM monthly downloads](https://img.shields.io/npm/dm/github-content.svg?style=flat)](https://npmjs.org/package/github-content)  [![NPM total downloads](https://img.shields.io/npm/dt/github-content.svg?style=flat)](https://npmjs.org/package/github-content) [![Linux Build Status](https://img.shields.io/travis/doowb/github-content.svg?style=flat&label=Travis)](https://travis-ci.org/doowb/github-content) [![Windows Build Status](https://img.shields.io/appveyor/ci/doowb/github-content.svg?style=flat&label=AppVeyor)](https://ci.appveyor.com/project/doowb/github-content)

> Easily download files from github raw user content.

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install --save github-content
```

## Usage

```js
var githubContent = require('github-content');
```

## API

### [GithubContent](index.js#L33)

Create an instance of GithubContent to setup downloading of files.

**Params**

* `options` **{Object}**: Options to set on instance. Additional options passed to [github-base](https://github.com/jonschlinkert/github-base)
* `options.owner` **{String}**: Set the owner to be used for each file.
* `options.repo` **{String}**: Set the repository to be used for each file.
* `options.branch` **{String}**: Set the branch to be used for each file. Defaults to `master`

**Example**

```js
var options = {
  owner: 'doowb',
  repo: 'github-content',
  branch: 'master' // defaults to master
};

var gc = new GithubContent(options);
```

### [.file](index.js#L73)

Download a single file given the file name and repository options. File object returned will contain a `.path` property with the file path passed in and a `.contents` property with the contents of the downloaded file.

**Params**

* `path` **{String}**: file path to download
* `options` **{Object}**: Additional options to base to [github-base](https://github.com/jonschlinkert/github-base) `.get` method.
* `cb` **{Function}**: Callback function taking `err` and `file`
* `returns` **{Object}** `this`: to enable chaining

**Example**

```js
gc.file('package.json', function(err, file) {
  if (err) return console.log(err);
  console.log(file.path);
  console.log(file.contents);
});
//=> package.json
//=> {
//=>   "name": "github-content"
//=>   ...
//=> }
```

### [.files](index.js#L129)

Download an array of files using the previous settings and the passed in file names. File objects returned will contain a `.path` property with the file path passed in and a `.contents` property with the contents of the downloaded file.

**Params**

* `files` **{String|Array}**: files to download
* `options` **{Object}**: Additional options to base to [github-base](https://github.com/jonschlinkert/github-base) `.get` method.
* `cb` **{Function}**: Callback function taking `err` and `files`
* `returns` **{Object}** `this`: to enable chaining

**Example**

```js
gc.files(['package.json', 'index.js'], function(err, files) {
  if (err) return console.log(err);
  console.log(files.length);
  console.log(files[0].path);
  console.log(files[0].contents);
});
//=> 2
//=> package.json
//=> {
//=>   "name": "github-content"
//=>   ...
//=> }
```

## About

### Related projects

[github-base](https://www.npmjs.com/package/github-base): JavaScript wrapper that greatly simplifies working with GitHub's API. | [homepage](https://github.com/jonschlinkert/github-base "JavaScript wrapper that greatly simplifies working with GitHub's API.")

### Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](../../issues/new).

### Building docs

_(This project's readme.md is generated by [verb](https://github.com/verbose/verb-generate-readme), please don't edit the readme directly. Any changes to the readme must be made in the [.verb.md](.verb.md) readme template.)_

To generate the readme, run the following command:

```sh
$ npm install -g verbose/verb#dev verb-generate-readme && verb
```

### Running tests

Running and reviewing unit tests is a great way to get familiarized with a library and its API. You can install dependencies and run tests with the following command:

```sh
$ npm install && npm test
```

### Author

**Brian Woodward**

* [github/doowb](https://github.com/doowb)
* [twitter/doowb](https://twitter.com/doowb)

### License

Copyright © 2017, [Brian Woodward](https://github.com/doowb).
Released under the [MIT License](LICENSE).

***

_This file was generated by [verb-generate-readme](https://github.com/verbose/verb-generate-readme), v0.6.0, on September 11, 2017._